# The tool for restore objects from AWS Glacier to AWS S3
There is no way to restre objects under one folder to AWS S3, this tool can help you do this

## prerequisite
1. take a look [here] to configure aws cli and ak, sk(https://docs.aws.amazon.com/zh_cn/cli/latest/userguide/cli-configure-quickstart.html#cli-configure-quickstart-config)

## install
```
pip install galcierestore
```

## how to use it
```
galcierestore
```
please fellow the prompt to fill the required arguments